pub enum RetryCircuitBreakerError<E, R> {
Service(E),
Retry(R),
Open(R),
}Expand description
An error from RetryCircuitBreaker.
Variants
Service(E)
The inner service returned a readiness error or a final request error that will not be retried.
Retry(R)
The inner service was called and completed, and Policy::retry returned Some(backoff).
Open(R)
The circuit breaker was already in backoff at call time, so the inner service was not called.